<?php
/**
 * discovery functions and definitions
 *
 * @package discovery
 * @since discovery 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since discovery 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 654; /* pixels */

if ( ! function_exists( 'discovery_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since discovery 1.0
 */
function discovery_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/tweaks.php' );

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on discovery, use a find and replace
	 * to change 'discovery' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'discovery', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'discovery' ),
	) );
	
	/**
	 * Add support for post thumbnails
	 */
	add_theme_support('post-thumbnails');
	add_image_size( 100, 300, true);
	add_image_size( 'featured', 670, 300, true );
	add_image_size( 'recent', 700, 400, true );

	/**
	 * Add support for the Aside Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', ) );
}
endif; // discovery_setup
add_action( 'after_setup_theme', 'discovery_setup' );

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * Hooks into the after_setup_theme action.
 *
 * @since discovery 1.0
 */
function discovery_register_custom_background() {
	$args = array(
		'default-color' => 'EEE',
	);

	$args = apply_filters( 'discovery_custom_background_args', $args );

	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	} else {
		define( 'BACKGROUND_COLOR', $args['default-color'] );
		define( 'BACKGROUND_IMAGE', $args['default-image'] );
		add_theme_support( 'custom-background', $args );
	}
}
add_action( 'after_setup_theme', 'discovery_register_custom_background' );

/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since discovery 1.0
 */
function discovery_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Primary Sidebar', 'discovery' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Secondary Sidebar', 'discovery' ),
		'id' => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Left Sidebar', 'discovery' ),
		'id' => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar(array(
			'name' => 'Left Footer Column',
			'id'   => 'left_column',
			'description'   => 'Widget area for footer left column',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>'
		));
		register_sidebar(array(
			'name' => 'Center  Footer Column',
			'id'   => 'center_column',
			'description'   => 'Widget area for footer center column',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>'
		));
		register_sidebar(array(
			'name' => 'Right Footer Column',
			'id'   => 'right_column',
			'description'   => 'Widget area for footer right column',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4>',
			'after_title'   => '</h4>'
		));

}
add_action( 'widgets_init', 'discovery_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function discovery_scripts() {
	wp_enqueue_style( 'style', get_stylesheet_uri() );
	
	if (!is_admin()) {
	wp_enqueue_script( 'small-menu', get_template_directory_uri() . '/js/small-menu.js', array( 'jquery' ), '20120206', true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
	
	if (!is_admin()) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
	
	if (!is_admin()) {
		wp_enqueue_script( 'smoothup', get_template_directory_uri() . '/js/smoothscroll.js', array( 'jquery' ), '',  true );
	}
	
	if (!is_admin()) {
	wp_enqueue_style('animate', get_template_directory_uri().'/css/animate.min.css');
	}
	
	if (!is_admin()) {
	wp_enqueue_script( 'inview', get_template_directory_uri() . '/js/Inview.js', array('jquery'));
	}
	
	if (!is_admin()) {
	wp_enqueue_script( 'theme-js', get_template_directory_uri() . '/js/animate.js', array('jquery', 'inview'));
	}
}
add_action( 'wp_enqueue_scripts', 'discovery_scripts' );

/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );


/**
 * Implement homepage slider files
 */

function discovery_add_scripts() {
	if (!is_admin()) {
    wp_enqueue_script('flexslider', get_template_directory_uri().'/js/jquery.flexslider-min.js', array('jquery'));
    wp_enqueue_script('flexslider-init', get_template_directory_uri().'/js/flexslider-init.js', array('jquery', 'flexslider'));
	}
}
add_action('wp_enqueue_scripts', 'discovery_add_scripts');

function discovery_add_styles() {
    wp_enqueue_style('flexslider', get_template_directory_uri().'/js/flexslider.css');
}
add_action('wp_enqueue_scripts', 'discovery_add_styles');

/**
 * Implement excerpt for homepage slider
 */
function get_slider_excerpt(){
$excerpt = get_the_content();
$excerpt = preg_replace(" (\[.*?\])",'',$excerpt);
$excerpt = strip_shortcodes($excerpt);
$excerpt = strip_tags($excerpt);
$excerpt = substr($excerpt, 0, 150);
$excerpt = substr($excerpt, 0, strripos($excerpt, " "));
$excerpt = trim(preg_replace( '/\s+/', ' ', $excerpt));
return $excerpt;
}


/**
* Global Customizer Settings
*/

/**
* Customizer additions
*/
	require( get_template_directory() . '/inc/customizer.php' );

/**
 * Implement the Custom Logo feature
 */
function discovery_theme_customizer( $wp_customize ) {
   
   $wp_customize->add_section( 'discovery_logo_section' , array(
    'title'       => __( 'Logo', 'discovery' ),
    'description' => __( 'Upload a logo to replace the default site name and description in the header', 'discovery' ),
	'priority'    => 30,
) );

   $wp_customize->add_setting( 'discovery_logo' );

   $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'discovery_logo', array(
    'label'    => __( 'Logo', 'discovery' ),
    'section'  => 'discovery_logo_section',
    'settings' => 'discovery_logo',
) ) );

}
add_action('customize_register', 'discovery_theme_customizer');

/**
 * Adds the individual section for contact details
 */
function telnumber_customizer( $wp_customize ) {
	
    $wp_customize->add_section( 'telnumber_section_one', array(
     'title'       => __( 'Contact Details', 'discovery' ),
     'description' => __( 'This is a settings section to change the contact details in the header.', 'discovery' ),
     'priority'    => 40,
        )
    );
	
	$wp_customize->add_setting(
    'telnumber_textbox_header_one', array(
    'default' => __( 'Default Contact Details', 'discovery' ),
    'sanitize_callback' => 'discovery_sanitize_text',
    )
	);
	
	$wp_customize->add_control(
	'telnumber_textbox_header_one', array(
	'label'    => __( 'Contact Details Text', 'discovery' ),
	'section' => 'telnumber_section_one',
	'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'telnumber_customizer' );


/**
 * Custom Homepage Customizer Options
 */
/**
 * Adds the individual section for featured text box top
 */
function discovery_customizer( $wp_customize ) {
	
    $wp_customize->add_section( 'featured_section_top', array(
    'title'       => __( 'Custom Homepage - Featured Text Area', 'discovery' ),
    'description' => __( 'This is a settings section to change the homepage featured text area.', 'discovery' ),
    'priority' => 135,
        )
    );
	
	$wp_customize->add_setting(
    'featured_textbox', array(
    'default' => __( 'Default Featured Text', 'discovery' ),
    'sanitize_callback' => 'discovery_sanitize_text',
    )
);

$wp_customize->add_control(
    'featured_textbox', array(
    'label'    => __( 'Featured Text Header', 'discovery' ),
    'section' => 'featured_section_top',
    'type' => 'text',
    )
);

$wp_customize->add_setting( 'featured_button_url' );
	
	$wp_customize->add_control(
		'featured_button_url',
		array(
			'label'    => __( 'Featured Button url', 'discovery' ),
			'section' => 'featured_section_top',
			'type' => 'text',
		)
	);
}
add_action( 'customize_register', 'discovery_customizer' );


/**
 * Adds the individual section for Services box 1
 */
function featured_text_one_customizer( $wp_customize ) {
    $wp_customize->add_section(
    'featured_section_one', array(
    'title' => __( 'Custom Homepage - Services Box 1', 'discovery' ),
    'description' => __( 'This is a settings section to change the custom homepage services box 1.', 'discovery' ),
    'priority' => 150,
        )
    );
	
	$wp_customize->add_setting( 'header-one-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'header-one-file-upload',
        array(
            'label' => __( 'Header Image One File Upload', 'discovery' ),
            'section' => 'featured_section_one',
            'settings' => 'header-one-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting(
    'featured_textbox_header_one',
    array(
        'default' => __( 'Default featured text Header', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_text',
    )
	);
	
	$wp_customize->add_control(
		'featured_textbox_header_one',
		array(
			'label' => __( 'Featured Header Text', 'discovery' ),
			'section' => 'featured_section_one',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting( 'header_one_url',
    array(
        'default' => __( 'Header One Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'header_one_url',
		array(
			'label'    => __( 'Header url', 'discovery' ),
			'section' => 'featured_section_one',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'featured_textbox_text_one',
		array(
			'default' => __( 'Default featured text', 'discovery' ),
			'sanitize_callback' => 'discovery_sanitize_text',
		)
	);
	
	$wp_customize->add_control(
		'featured_textbox_text_one',
		array(
			'label' => __( 'Featured text', 'discovery' ),
			'section' => 'featured_section_one',
			'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'featured_text_one_customizer' );

/**
 * Adds the individual section for Services box 2
 */
function featured_text_two_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'featured_section_two',
        array(
            'title' => __( 'Custom Homepage - Services Box 2', 'discovery' ),
            'description' => __( 'This is a settings section to change the custom homepage services box 2.', 'discovery' ),
            'priority' => 155,
        )
    );
	
	$wp_customize->add_setting( 'header-two-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'header-two-file-upload',
        array(
            'label' => __( 'Header Image Two File Upload', 'discovery' ),
            'section' => 'featured_section_two',
            'settings' => 'header-two-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting(
    'featured_textbox_header_two',
    array(
        'default' => __( 'Default featured text Header', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_text',
    )
	);
	
	$wp_customize->add_control(
		'featured_textbox_header_two',
		array(
			'label' => __( 'Featured Header text', 'discovery' ),
			'section' => 'featured_section_two',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting( 'header_two_url',
    array(
        'default' => __( 'Header Two Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'header_two_url',
		array(
			'label'    => __( 'Header url', 'discovery' ),
			'section' => 'featured_section_two',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'featured_textbox_text_two',
		array(
			'default' => __( 'Default featured text', 'discovery' ),
			'sanitize_callback' => 'discovery_sanitize_text',
		)
	);
	
	$wp_customize->add_control(
		'featured_textbox_text_two',
		array(
			'label' => __( 'Featured text', 'discovery' ),
			'section' => 'featured_section_two',
			'type' => 'text',
		)
	);
}
add_action( 'customize_register', 'featured_text_two_customizer' );

/**
 * Adds the individual section for services box 3
 */
function featured_text_three_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'featured_section_three',
        array(
            'title' => __( 'Custom Homepage - Services Box 3', 'discovery' ),
            'description' => __( 'This is a settings section to change the custom homepage services box 3.', 'discovery' ),
            'priority' => 160,
        )
    );
	
	$wp_customize->add_setting( 'header-three-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'header-three-file-upload',
        array(
            'label' => __( 'Header Image Three File Upload', 'discovery' ),
            'section' => 'featured_section_three',
            'settings' => 'header-three-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting(
    'featured_textbox_header_three',
    array(
        'default' => __( 'Default featured text Header', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_text',
    )
	);
	
	$wp_customize->add_control(
		'featured_textbox_header_three',
		array(
			'label' => __( 'Featured Header text', 'discovery' ),
			'section' => 'featured_section_three',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting( 'header_three_url',
    array(
        'default' => __( 'Header Three Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'header_three_url',
		array(
			'label'    => __( 'Header url', 'discovery' ),
			'section' => 'featured_section_three',
			'type' => 'text',
		)
	);

	
	$wp_customize->add_setting(
		'featured_textbox_text_three',
		array(
			'default' => __( 'Default featured text', 'discovery' ),
			'sanitize_callback' => 'discovery_sanitize_text',
		)
	);
	
	$wp_customize->add_control(
		'featured_textbox_text_three',
		array(
			'label' => __( 'Featured text', 'discovery' ),
			'section' => 'featured_section_three',
			'type' => 'text',
		)
	);
}
add_action( 'customize_register', 'featured_text_three_customizer' );


/**
 * Adds the individual section for Partner logo 1
 */
function client_logo_one_customizer( $wp_customize ) {
    $wp_customize->add_section(
    'logo_section_one', array(
    'title' => __( 'Custom Homepage - Partners logo 1', 'discovery' ),
    'description' => __( 'This is a settings section to change the Custom Homepage Partners logo 1.', 'discovery' ),
    'priority' => 850,
        )
    );

	$wp_customize->add_setting( 'logo-one-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'logo-one-file-upload',
        array(
            'label' => __( 'Client logo One File Upload', 'discovery' ),
            'section' => 'logo_section_one',
            'settings' => 'logo-one-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting( 'logo_one_url',
    array(
        'default' => __( 'logo One Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'logo_one_url',
		array(
			'label'    => __( 'Client logo one url', 'discovery' ),
			'section' => 'logo_section_one',
			'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'client_logo_one_customizer' );


/**
 * Adds the individual section for Partner logo 2
 */
function client_logo_two_customizer( $wp_customize ) {
    $wp_customize->add_section(
    'logo_section_two', array(
    'title' => __( 'Custom Homepage - Partners logo 2', 'discovery' ),
    'description' => __( 'This is a settings section to change the Custom Homepage Partners logo 2.', 'discovery' ),
    'priority' => 900,
        )
    );

	$wp_customize->add_setting( 'logo-two-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'logo-two-file-upload',
        array(
            'label' => __( 'Client logo two File Upload', 'discovery' ),
            'section' => 'logo_section_two',
            'settings' => 'logo-two-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting( 'logo_two_url',
    array(
        'default' => __( 'logo two Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'logo_two_url',
		array(
			'label'    => __( 'Client logo two url', 'discovery' ),
			'section' => 'logo_section_two',
			'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'client_logo_two_customizer' );


/**
 * Adds the individual section for Partner logo 3
 */
function client_logo_three_customizer( $wp_customize ) {
    $wp_customize->add_section(
    'logo_section_three', array(
    'title' => __( 'Custom Homepage - Partners logo 3', 'discovery' ),
    'description' => __( 'This is a settings section to change the Custom Homepage Partners logo 3.', 'discovery' ),
    'priority' => 950,
        )
    );

	$wp_customize->add_setting( 'logo-three-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'logo-three-file-upload',
        array(
            'label' => __( 'Client logo three File Upload', 'discovery' ),
            'section' => 'logo_section_three',
            'settings' => 'logo-three-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting( 'logo_three_url',
    array(
        'default' => __( 'logo three Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'logo_three_url',
		array(
			'label'    => __( 'Client logo three url', 'discovery' ),
			'section' => 'logo_section_three',
			'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'client_logo_three_customizer' );


/**
 * Adds the individual section for Partner logo 4
 */
function client_logo_four_customizer( $wp_customize ) {
    $wp_customize->add_section(
    'logo_section_four', array(
    'title' => __( 'Custom Homepage - Partners logo 4', 'discovery' ),
    'description' => __( 'This is a settings section to change the Custom Homepage Partners logo 4.', 'discovery' ),
    'priority' => 1000,
        )
    );

	$wp_customize->add_setting( 'logo-four-file-upload' );
 
	$wp_customize->add_control(
    new WP_Customize_Upload_Control(
        $wp_customize,
        'logo-four-file-upload',
        array(
            'label' => __( 'Client logo four File Upload', 'discovery' ),
            'section' => 'logo_section_four',
            'settings' => 'logo-four-file-upload'
        )
    )
	);
	
	$wp_customize->add_setting( 'logo_four_url',
    array(
        'default' => __( 'logo four Link', 'discovery' ),
		'sanitize_callback' => 'discovery_sanitize_url',
    ) );
	
	$wp_customize->add_control(
		'logo_four_url',
		array(
			'label'    => __( 'Client logo four url', 'discovery' ),
			'section' => 'logo_section_four',
			'type' => 'text',
		)
	);

}
add_action( 'customize_register', 'client_logo_four_customizer' );

/**
 * sanitize customizer text input
 */
 function discovery_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function discovery_sanitize_url( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function discovery_sanitize_html( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

add_filter( 'wp_title', 'discovery_wp_title' );


/**
 * Implement excerpt for homepage thumbnails
 */
function content($limit) {
  $content = explode(' ', get_the_content(), $limit);
  if (count($content)>=$limit) {
    array_pop($content);
    $content = implode(" ",$content).'...';
  } else {
    $content = implode(" ",$content);
  }	
  $content = preg_replace('/\[.+\]/','', $content);
  $content = apply_filters('the_content', $content); 
  $content = str_replace(']]>', ']]&gt;', $content);
  return $content;
}

/**
 * Filters the page title appropriately depending on the current page
 *
 * This function is attached to the 'wp_title' fiilter hook.
 *
 * @uses	home_url()
 * @uses	is_home()
 * @uses	is_front_page()
 */
function discovery_wp_title( $title ) {
	global $page, $paged;

	if ( is_feed() )
		return $title;

	$site_description = get_bloginfo( 'description' );

	$filtered_title = $title . get_bloginfo( 'name' );
	$filtered_title .= ( ! empty( $site_description ) && ( is_home() || is_front_page() ) ) ? ' | ' . $site_description: '';
	$filtered_title .= ( 2 <= $paged || 2 <= $page ) ? ' | ' . sprintf( __( 'Page %s', 'discovery' ), max( $paged, $page ) ) : '';

	return $filtered_title;
}
 
/**
 * Breadcrumbs
 *
 * This functions displays page breadcrumbs
 */
function discovery_breadcrumbs() {
 
	/* === OPTIONS === */
	$text['home']     = 'Home'; // text for the 'Home' link
	$text['category'] = 'Archive by Category "%s"'; // text for a category page
	$text['search']   = 'Search Results for "%s" Query'; // text for a search results page
	$text['tag']      = 'Posts Tagged "%s"'; // text for a tag page
	$text['author']   = 'Articles Posted by %s'; // text for an author page
	$text['404']      = 'Error 404'; // text for the 404 page
 
	$show_current   = 1; // 1 - show current post/page/category title in breadcrumbs, 0 - don't show
	$show_on_home   = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
	$show_home_link = 1; // 1 - show the 'Home' link, 0 - don't show
	$show_title     = 1; // 1 - show the title for the links, 0 - don't show
	$delimiter      = ' / '; // delimiter between crumbs
	$before         = '<span class="current">'; // tag before the current crumb
	$after          = '</span>'; // tag after the current crumb
	/* === END OF OPTIONS === */
 
	global $post;
	$home_link    = home_url('/');
	$link_before  = '<span typeof="v:Breadcrumb">';
	$link_after   = '</span>';
	$link_attr    = ' rel="v:url" property="v:title"';
	$link         = $link_before . '<a' . $link_attr . ' href="%1$s">%2$s</a>' . $link_after;
	$parent_id    = $parent_id_2 = $post->post_parent;
	$frontpage_id = get_option('page_on_front');
 
	if (is_home() || is_front_page()) {
 
		if ($show_on_home == 1) echo '<div class="breadcrumbs"><a href="' . $home_link . '">' . $text['home'] . '</a></div>';
 
	} else {
 
		echo '<div class="breadcrumbs" xmlns:v="http://rdf.data-vocabulary.org/#">';
		if ($show_home_link == 1) {
			echo '<a href="' . $home_link . '" rel="v:url" property="v:title">' . $text['home'] . '</a>';
			if ($frontpage_id == 0 || $parent_id != $frontpage_id) echo $delimiter;
		}
 
		if ( is_category() ) {
			$this_cat = get_category(get_query_var('cat'), false);
			if ($this_cat->parent != 0) {
				$cats = get_category_parents($this_cat->parent, TRUE, $delimiter);
				if ($show_current == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
				$cats = str_replace('<a', $link_before . '<a' . $link_attr, $cats);
				$cats = str_replace('</a>', '</a>' . $link_after, $cats);
				if ($show_title == 0) $cats = preg_replace('/ title="(.*?)"/', '', $cats);
				echo $cats;
			}
			if ($show_current == 1) echo $before . sprintf($text['category'], single_cat_title('', false)) . $after;
 
		} elseif ( is_search() ) {
			echo $before . sprintf($text['search'], get_search_query()) . $after;
 
		} elseif ( is_day() ) {
			echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
			echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
			echo $before . get_the_time('d') . $after;
 
		} elseif ( is_month() ) {
			echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
			echo $before . get_the_time('F') . $after;
 
		} elseif ( is_year() ) {
			echo $before . get_the_time('Y') . $after;
 
		} elseif ( is_single() && !is_attachment() ) {
			if ( get_post_type() != 'post' ) {
				$post_type = get_post_type_object(get_post_type());
				$slug = $post_type->rewrite;
				printf($link, $home_link . '/' . $slug['slug'] . '/', $post_type->labels->singular_name);
				if ($show_current == 1) echo $delimiter . $before . get_the_title() . $after;
			} else {
				$cat = get_the_category(); $cat = $cat[0];
				$cats = get_category_parents($cat, TRUE, $delimiter);
				if ($show_current == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
				$cats = str_replace('<a', $link_before . '<a' . $link_attr, $cats);
				$cats = str_replace('</a>', '</a>' . $link_after, $cats);
				if ($show_title == 0) $cats = preg_replace('/ title="(.*?)"/', '', $cats);
				echo $cats;
				if ($show_current == 1) echo $before . get_the_title() . $after;
			}
 
		} elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
			$post_type = get_post_type_object(get_post_type());
			echo $before . $post_type->labels->singular_name . $after;
 
		} elseif ( is_attachment() ) {
			$parent = get_post($parent_id);
			$cat = get_the_category($parent->ID); $cat = $cat[0];
			$cats = get_category_parents($cat, TRUE, $delimiter);
			$cats = str_replace('<a', $link_before . '<a' . $link_attr, $cats);
			$cats = str_replace('</a>', '</a>' . $link_after, $cats);
			if ($show_title == 0) $cats = preg_replace('/ title="(.*?)"/', '', $cats);
			echo $cats;
			printf($link, get_permalink($parent), $parent->post_title);
			if ($show_current == 1) echo $delimiter . $before . get_the_title() . $after;
 
		} elseif ( is_page() && !$parent_id ) {
			if ($show_current == 1) echo $before . get_the_title() . $after;
 
		} elseif ( is_page() && $parent_id ) {
			if ($parent_id != $frontpage_id) {
				$breadcrumbs = array();
				while ($parent_id) {
					$page = get_page($parent_id);
					if ($parent_id != $frontpage_id) {
						$breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
					}
					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse($breadcrumbs);
				for ($i = 0; $i < count($breadcrumbs); $i++) {
					echo $breadcrumbs[$i];
					if ($i != count($breadcrumbs)-1) echo $delimiter;
				}
			}
			if ($show_current == 1) {
				if ($show_home_link == 1 || ($parent_id_2 != 0 && $parent_id_2 != $frontpage_id)) echo $delimiter;
				echo $before . get_the_title() . $after;
			}
 
		} elseif ( is_tag() ) {
			echo $before . sprintf($text['tag'], single_tag_title('', false)) . $after;
 
		} elseif ( is_author() ) {
	 		global $author;
			$userdata = get_userdata($author);
			echo $before . sprintf($text['author'], $userdata->display_name) . $after;
 
		} elseif ( is_404() ) {
			echo $before . $text['404'] . $after;
		}
 
		if ( get_query_var('paged') ) {
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
			echo __('Page', 'discovery') . ' ' . get_query_var('paged');
			if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
		}
 
		echo '</div><!-- .breadcrumbs -->';
 
	}
} // end discovery_breadcrumbs()

/**
 * Custom "more" link format
 */
function new_excerpt_more($more) {
       global $post;
	return '...';
}
add_filter('excerpt_more', 'new_excerpt_more');